@@ -1,6 +1,6 @@
 use utf8;
 package CPAN::Testers::API::Base;
-our $VERSION = '0.003';
+our $VERSION = '0.004';
 # ABSTRACT: Base module for importing standard modules, features, and subs
 
 #pod =head1 SYNOPSIS
@@ -38,8 +38,8 @@ use base 'Import::Base';
 
 our @IMPORT_MODULES = (
     'strict', 'warnings',
-    feature => [qw( :5.24 signatures )],
-    '-warnings' => [qw( experimental::signatures )],
+    feature => [qw( :5.24 signatures refaliasing )],
+    '-warnings' => [qw( experimental::signatures experimental::refaliasing )],
 );
 
 our %IMPORT_BUNDLES = (
@@ -62,7 +62,7 @@ CPAN::Testers::API::Base - Base module for importing standard modules, features,
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 SYNOPSIS
 
